@@ -1,6 +1,6 @@
 weightitMSM <- function(formula.list, data = NULL, method = "ps", stabilize = FALSE, by = NULL, s.weights = NULL,
                         num.formula = NULL, moments = 1L, int = FALSE,
-                        verbose = FALSE, include.obj = FALSE, is.MSM.method, ...) {
+                        verbose = FALSE, include.obj = FALSE, is.MSM.method, weightit.force = FALSE, ...) {
 
   A <- list(...)
 
@@ -11,41 +11,24 @@ weightitMSM <- function(formula.list, data = NULL, method = "ps", stabilize = FA
   #Checks
 
   ##Process method
-  bad.method <- FALSE
-  acceptable.methods <- c("ps",
-                          "gbm", "twang", "gbr",
-                          "cbps",
-                          "npcbps",
-                          "ebal", "entropy", "ebalance",
-                          "sbw",
-                          "ebcw", "ate",
-                          "optweight", "opt",
-                          "super", "superlearner")
-
-  if (is_null(method) || length(method) > 1) bad.method <- TRUE
-  else if (is.character(method)) {
-    if (tolower(method) %nin% acceptable.methods) bad.method <- TRUE
-  }
-  else if (!is.function(method)) bad.method <- TRUE
-
-  if (bad.method) stop("method must be a string of length 1 containing the name of an acceptable weighting method or a function that produces weights.", call. = FALSE)
+  check.acceptable.method(method, msm = TRUE, force = weightit.force)
 
   if (is.character(method)) {
     method <- method.to.proper.method(method)
     attr(method, "name") <- method
     if (missing(is.MSM.method)) is.MSM.method <- NULL
-    is.MSM.method <- check.MSM.method(method, is.MSM.method)
+    is.MSM.method <- process.MSM.method(is.MSM.method, method)
   }
   else if (is.function(method)) {
     method.name <- paste(deparse(substitute(method)))
-    method <- check.user.method(method)
+    check.user.method(method)
     if (missing(is.MSM.method)) is.MSM.method <- NULL
-    is.MSM.method <- check.MSM.method(method, is.MSM.method)
+    is.MSM.method <- process.MSM.method(is.MSM.method, method)
     attr(method, "name") <- method.name
   }
 
   #Process moments and int
-  moments.int <- check.moments.int(method, moments, int)
+  moments.int <- process.moments.int(moments, int, method)
   moments <- moments.int["moments"]; int <- moments.int["int"]
 
   s.weights <- process.s.weights(s.weights, data)
@@ -105,10 +88,10 @@ weightitMSM <- function(formula.list, data = NULL, method = "ps", stabilize = FA
 
     n <- length(treat.list[[i]])
 
-    if (any(is.na(reported.covs.list[[i]])) || nrow(reported.covs.list[[i]]) != n) {
+    if (anyNA(reported.covs.list[[i]]) || nrow(reported.covs.list[[i]]) != n) {
       warning("Missing values are present in the covariates. See ?weightit for information on how these are handled.", call. = FALSE)
     }
-    if (any(is.na(treat.list[[i]]))) {
+    if (anyNA(treat.list[[i]])) {
       stop(paste0("No missing values are allowed in the treatment variable. Missing values found in ", treat.name, "."), call. = FALSE)
     }
 
@@ -129,8 +112,6 @@ weightitMSM <- function(formula.list, data = NULL, method = "ps", stabilize = FA
   if (verbose) eval.verbose <- base::eval
   else eval.verbose <- utils::capture.output
 
-  obj.list <- NULL
-
   if (is.MSM.method) {
     eval.verbose({
       #Returns weights (w)
@@ -146,9 +127,9 @@ weightitMSM <- function(formula.list, data = NULL, method = "ps", stabilize = FA
                                             is.MSM.method = TRUE,
                                             include.obj = include.obj), A))
     })
-    w <- obj$w
+    w <- obj[["w"]]
     stabout <- NULL
-    obj.list <- obj$fit.obj
+    obj.list <- obj[["fit.obj"]]
   }
   else {
     A[["estimand"]] <- NULL
@@ -159,6 +140,8 @@ weightitMSM <- function(formula.list, data = NULL, method = "ps", stabilize = FA
     # if (length(A[["family"]]) %nin% c(0, 1, length(formula.list))) stop(paste0("The argument to link must have length 1 or ", length(formula.list), "."), call. = FALSE)
     # if (length(A[["family"]]) == 1) A[["family"]] <- rep(A[["family"]], length(formula.list))
 
+    obj.list <- vector("list", length(formula.list))
+
     for (i in seq_along(formula.list)) {
       A_i <- A
       if (is_not_null(A[["link"]])) A_i[["link"]] <- A[["link"]][[i]]
@@ -185,6 +168,7 @@ weightitMSM <- function(formula.list, data = NULL, method = "ps", stabilize = FA
       })
       w.list[[i]] <- obj[["w"]]
       ps.list[[i]] <- obj[["ps"]]
+      obj.list[[i]] <- obj[["fit.obj"]]
 
       if (stabilize) {
         #Process stabilization formulas and get stab weights
